@@ -36,7 +36,7 @@ class Speakeasy(object):
         self.legacy_socket = None
         if self.legacy:
             if os.path.exists(self.legacy):
-                logger.warn('Remove existing legacy socket and recreating'.format(self.legacy))
+                logger.warn('Remove existing legacy socket "{0}" and recreating'.format(self.legacy))
                 os.remove(self.legacy)
             self.legacy_socket = socket.socket(socket.AF_UNIX, socket.SOCK_DGRAM)
             self.legacy_socket.bind(self.legacy)
@@ -45,9 +45,9 @@ class Speakeasy(object):
         # Process the args for emitter
         self.emitter_args = {}
         if emitter_args:
-                for arg in emitter_args:
-                    k, v = arg.split('=')
-                    self.emitter_args[k] = v
+            for arg in emitter_args:
+                k, v = arg.split('=')
+                self.emitter_args[k] = v
 
         # Setup the emitter
         self.emitter = import_emitter(self.emitter_name, **self.emitter_args)
@@ -74,7 +74,8 @@ class Speakeasy(object):
         self.poller = zmq.Poller()
         self.poller.register(self.recv_socket, zmq.POLLIN)
         self.poller.register(self.cmd_socket, zmq.POLLIN)
-        self.poller.register(self.legacy_socket, zmq.POLLIN)
+        if self.legacy_socket:
+            self.poller.register(self.legacy_socket, zmq.POLLIN)
 
         # Setup poll and emit thread
         self.poll_thread = threading.Thread(target=self.poll_sockets, args=())
@@ -199,7 +200,7 @@ class Speakeasy(object):
                 # Process command
                 self.process_command(cmd)
 
-            if socks.get(self.legacy_socket_fno) == zmq.POLLIN:
+            if self.legacy and socks.get(self.legacy_socket_fno) == zmq.POLLIN:
                 # Process legacy format
                 try:
                     data, addr = self.legacy_socket.recvfrom(8192)
